div.changelog {
    cursor:text;
    font-family:Monaco, Consolas, 'DejaVu Sans Mono', 'Droid Sans Mono', Monospace;
    font-size:14px;
    padding:1em;
    border:1px solid #777777;
    color:#222222;
    background-color:#eff3f2;
    word-wrap:break-word;
    max-width:640px;
    display: inline-block;
    text-align:left;
}

pre.wrap {
    white-space:pre-wrap;
}
