body {
    padding-left:15px;
    padding:5px;
    background-color:White;
    color:Black;
}

h1 {
    font-size:1.7em;
    margin:0px;
    padding:0px;
}

hr {
    color:Black;
    background-color:Black;
    height:1px;
    border:0;
}

.tool {
    font-size:1.55em;
}

a.tool {
    text-decoration:none;
    color:Black;
}

div.sponsor, div.become_sponsor {
    padding-left:80px;
    font-size:1.7em;
    font-weight:bold;
    color:#ACACAC;
}

div.sponsor {
    font-size:1.7em;
}

img.sponsor {
    height:50px;
    padding-left:5px;
}

.rss {
    height:1.2em;
    vertical-align:bottom;
}
